@@ -40,8 +40,6 @@ class Extractor(QtCore.QObject):
       self.online = b
 
    def InitNetwork(self):
-#      DebugLog("Extractor::InitNetwork")
-
       self.manager2 = QNetworkAccessManager()
       self.manager = QNetworkAccessManager()
       self.connect(self.manager, QtCore.SIGNAL("finished(QNetworkReply *)"), self.readResponse )
@@ -51,7 +49,6 @@ class Extractor(QtCore.QObject):
          o = urlparse(proxy)
          netlocL = o.netloc.find(':')
          host = o.netloc[:netlocL]
-#         DebugLog("  - Using proxy : %s://%s:%d"%(o.scheme, host, o.port))
          self.proxy = QNetworkProxy(QNetworkProxy.HttpProxy, host, o.port)
          self.manager.setProxy(self.proxy)
          self.manager2.setProxy(self.proxy)
@@ -74,6 +71,7 @@ class Extractor(QtCore.QObject):
 
       if self.online and self.manager:
          request = QNetworkRequest( QtCore.QUrl(self.url) )
+         request.setRawHeader("User-Agent","Mozilla/5.0");
          reply = self.manager.get(request)
          self.connect(reply, QtCore.SIGNAL("downloadProgress(qint64, qint64)"), self.updateBar)
 
@@ -90,11 +88,13 @@ class Extractor(QtCore.QObject):
       DebugLog("Extractor::readResponse %s"%self.id)
       error = reply.error()
 
+      html = str(reply.readAll())
+
       # test d'erreur, en général, pas de connection internet
       if error != QNetworkReply.NoError:
-         self.rideModel.SetInfo('ERROR', u"Erreur, vérifiez votre connection Internet")
+         DebugLog(html)
+         self.rideModel.SetInfo('ERROR', u"Erreur %d, vérifiez votre connection Internet"%error)
 
-      html = str(reply.readAll())
       #DebugFile(html)
 
       if self.parsePerturbation:
@@ -103,12 +103,11 @@ class Extractor(QtCore.QObject):
 
       elif self.parseDetails:
          self.ParseDetails(html, reply)
-         
+
       else:
          self.Parse(html)
 
       if self.extracted:
-         self.fillModel(self.max)
          self.emit(QtCore.SIGNAL('extracted'), self.rideModel)
          self.fetching = False
 
@@ -121,11 +120,13 @@ class Extractor(QtCore.QObject):
          print e
 
       self.extracted = True
-      
+
       if self.online:
          if self.perturbation:
+            DebugLog("perturbation : %s"%self.urlPerturb)
             self.parsePerturbation =  True
             request = QNetworkRequest( QtCore.QUrl( self.urlPerturb ) )
+            request.setRawHeader("User-Agent","Mozilla/5.0");
             self.manager.get(request)
 
          if self.parseDetails:
@@ -133,10 +134,14 @@ class Extractor(QtCore.QObject):
             self.cpt=0
             for ride in self.listRides:
                if ride.detailsUrl:
+                  #DebugLog("details : %s"%self.urlPerturb)
                   request = QNetworkRequest( QtCore.QUrl(ride.detailsUrl) )
                   request.setRawHeader("User-Agent","Mozilla/5.0");
                   self.manager.get(request)
 
+      if self.extracted:
+         self.fillModel(self.max)
+                  
       if self.error:
          self.rideModel.SetInfo('ERROR', self.error)
 
@@ -144,6 +149,7 @@ class Extractor(QtCore.QObject):
       pass
 
    def ParseDetails(self, html, reply):
+      DebugLog("Extractor::ParseDetails")
       self.cpt += 1
       for ride in self.listRides:
          if ride.detailsUrl==reply.url().toString():
@@ -154,6 +160,9 @@ class Extractor(QtCore.QObject):
          self.parseDetails = False
          self.extracted = True
 
+      if self.extracted:
+         self.fillModel(self.max)
+         
    def AppendRidesToModel(self, imax):
       DebugLog("Extractor::AppendRidesToModel %s"%self.id)
       DebugLog("  len(self.listRides)=%d"%len(self.listRides))
