@@ -31,6 +31,7 @@ class TableParserMetro(Extractor, HTMLParser.HTMLParser):
       self.stopParsing = False
 
    def Feed(self, html):
+      DebugLog("TableParserMetro::Feed")
       self.Clear()
       self.html = htmlTools.unescape(html.strip().decode('iso-8859-1'))
       self.feed(self.html)
@@ -106,7 +107,6 @@ class TableParserMetro(Extractor, HTMLParser.HTMLParser):
       DebugLog("TableParserMetro::fillModel")
       self.AppendRidesToModel(imax)
       self.perturbation='perturb'
-      return self.perturbation, self.error
 
    def ParsePerturbation(self, str):
       DebugLog("TableParserMetro::ParsePerturbation")
