@@ -73,25 +73,26 @@ class TrainTrainModel(QAbstractTableModel):
          extractor = ExtractorRERratp(ligne)
 
       if extractor:
+         extractor.rideModel.sens = ligne.sens
          self.rideList[extractor.id] = extractor
          if save:
             self.AddRideModel( extractor.rideModel )
          self.connect(extractor, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
          extractor.SetOnline(self.online)
-         extractor.FetchDatas(self, self.max)
+         # extractor.FetchDatas(self, self.max)
          return extractor.rideModel
       else:
          return None
 
    def InitDatas(self):
       DebugLog("TrainTrainModel::InitDatas")
-
       self.garesConf.ReadRides()
       self.rideList = dict()
       self.reset()
-
       for ligne in self.garesConf.GetRides():
          self.CreateAndAddRide(ligne)
+      DebugLog("initialized")
+      self.emit(QtCore.SIGNAL('initialized'))   
 
    def Extracted(self, rideModel):
       self.emit(QtCore.SIGNAL('extracted'), rideModel)
